/*--------------------------------------|
|File:		 spi.c						|
|Date:   	 August 2011				|
|Author:	 J. Moertl					|
|Description:Source data to init and	|
|			 use spi					|
|--------------------------------------*/

#include "main.h"

/*--------------------------------------
Function:	spi_init()
Input:		---
Output:		---
Description:Initializes SPI
--------------------------------------*/
void spi_init(void)
{
        volatile uint8_t IOReg;

		// set PB3(MOSI), PB5(SCK), PB2(SS), PB1(CD) as output
        DDRB    |= (1<<PB3)|(1<<PB5)|(1<<DCS)|(1<<DCD);

		// enable SPI in Master Mode with SCK = CK/4, CPHA = 1
        SPCR    = (1<<SPE)|(1<<MSTR)|(1<<CPHA)|(1<<CPOL);

        IOReg   = SPSR;         //clear SPIF bit in SPSR
        IOReg   = SPDR;			//clear receive buffer
		PORTB |= (1<<DCD);		//SS high
		PORTB |= (1<<DCS);		//CD high
}




/*--------------------------------------
Function:	spi_byte()
Input:		data
Output:		---
Description:Sends one byte of data and
			wait until transfer is
			completed
--------------------------------------*/
uint8_t spi_byte (uint8_t data)
{

	SPDR = data; //send data
	while (!(SPSR & (1<<SPIF)));    // wait until byte is sent and received

	return SPDR; //return received data (not used with EA DOGS102-6,
				 //but you have to read out, because ATMega needs it
}


//----------------- EOF spi.c ------------